[m-rev.] trivial diff: put nondet environments on the heap for Java back-end

Michael Wybrow mjwybrow at students.cs.mu.oz.au
Thu Jan 24 13:24:17 AEDT 2002


===================================================================

Estimated hours taken: 0.25
Branches: main


mercury/compiler/handle_options.m:
	Added a line that says when we're compiling to Java we want to store
	nondet environments on the heap.

	

Index: handle_options.m
===================================================================
RCS file: /home/mercury1/repository/mercury/compiler/handle_options.m,v
retrieving revision 1.125
diff -u -r1.125 handle_options.m
--- handle_options.m	11 Jan 2002 07:44:29 -0000	1.125
+++ handle_options.m	24 Jan 2002 02:11:41 -0000
@@ -309,7 +309,8 @@
 
 	% Generating Java implies high-level code, turning off nested functions,
 	% using copy-out for both det and nondet output arguments,
 	% using no tags, not optimizing tailcalls and no static ground terms.
 	% XXX no static ground terms should be eliminated in a later
 	%     version.
 	% XXX The Java backend should eventually support optimizing tailcalls.
@@ -321,7 +322,8 @@
 		globals__io_set_option(det_copy_out, bool(yes)),
 		globals__io_set_option(num_tag_bits, int(0)),
 		globals__io_set_option(optimize_tailcalls, bool(no)),
-		globals__io_set_option(static_ground_terms, bool(no))
+		globals__io_set_option(static_ground_terms, bool(no)),
+		globals__io_set_option(put_nondet_env_on_heap, bool(yes))
 	;
 		[]
 	),

--------------------------------------------------------------------------
mercury-reviews mailing list
post:  mercury-reviews at cs.mu.oz.au
administrative address: owner-mercury-reviews at cs.mu.oz.au
unsubscribe: Address: mercury-reviews-request at cs.mu.oz.au Message: unsubscribe
subscribe:   Address: mercury-reviews-request at cs.mu.oz.au Message: subscribe
--------------------------------------------------------------------------
@@ -309,7 +309,8 @@
 	% Generating Java implies high-level code, turning off nested functions,
 	% using copy-out for both det and nondet output arguments,
-	% using no tags, not optimizing tailcalls and no static ground terms.
+	% using no tags, not optimizing tailcalls, no static ground terms and
+	% store nondet environments on the heap.
 	% XXX no static ground terms should be eliminated in a later
 	%     version.



More information about the reviews mailing list